@@ -42,19 +42,22 @@ def download_file(url, save_path):
         return e
 
 
-def execute(command, cwd='/'):
+def execute(command, cwd='/', login=False):
     """
     执行本地命令
     :param command: 命令
     :param cwd: 执行环境
     :return: 输出，错误信息(bytes类型)
     """
-    command = 'bash --login -c "%s" ' % command
+    if login:
+        command = 'bash --login -c "%s" ' % command
+
     sub = subprocess.Popen(command, cwd=cwd, stdin=subprocess.PIPE, stdout=subprocess.PIPE,
                            stderr=subprocess.PIPE, shell=True)
     (stdout, stderr) = sub.communicate(timeout=3600)
+    print(stdout.decode('utf-8', 'ignore'))
     if sub.returncode != 0:
-        raise Exception(stderr.decode('utf-8', 'ignore'), stdout.decode('utf-8', 'ignore'))
+        raise Exception(stderr.decode('utf-8', 'ignore'))
 
 
 def delete_dir_then_move_dir(file_from, file_to):
